<?php
/**
 * Controller to handling public actions
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Ajax_Public_actions' ))
{
  class IPCht_Ajax_Public_actions
  {
    //{{ exec

    /**
     * Execution save setting
     *
     * @return void
     */
    public function exec()
    {
      $modSetting = new IPCht_Model_Setting();
      $modSession = new IPCht_Model_Session();
      $modUser    = new IPCht_Model_User();
      $modChat    = new IPCht_Model_Chat();

      //Get system config
      $config = $modSetting->getSettings();

      //
      //Check admin online status
      $online = IPCht_Chat::isOnline();
      if ( $online ) {
        $adminStatus = 1;
      } else {
        $adminStatus = 0;
      }

      //Check session
      $session = IPCht_Chat::getSession();
      if ( ! $session )
      {
        echo json_encode( array(
          'status'       => 0,
          'admin_status' => $adminStatus,
          'message'      => __( 'Error chat session.', IPCHT_SLUG )
        ) );
        die();
      }

      //Check user
      $user = false;
      if ( ! empty( $session['user_id'] )) {
        $user = $modUser->getUser( $session['user_id'] );
      }
      if ( ! $user )
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => __( 'Error chat user.', IPCHT_SLUG )
        ) );
        die();
      }

      $returnData = array(
        'status'    => 1,
        'message'   => __( 'Success.', IPCHT_SLUG )
      );

      //
      //Set admin online status
      $returnData['admin_status'] = $adminStatus;

      //
      //Save user status
      $this->_saveUserStatus( $session, $user );

      //
      //Check admin chats
      $adminChats = IPCht_Chat::createAdminChats( $session );
      if ( ! empty( $adminChats['html'] ) ) {
        $returnData['admin_chats_status'] = 1;
      } else {
        $returnData['admin_chats_status'] = 0;
      }
      $returnData['admin_chats'] = $adminChats['html'];
      $returnData['last_chats']  = $adminChats['ids'];
      $returnData['last_date']   = $adminChats['last_date'];

      //
      //Try to save pending chat
      if ( ! empty( $_POST['messages'] ))
      {
        $success = $this->_saveMessages( $_POST['messages'], $session );
        $returnData['send_messages_status'] = $success;
      }

      echo json_encode( $returnData );
      die();
    }

    //}}
    //{{ _saveMessages

    /**
     * Save chat
     *
     * @param  array  $messages
     * @param  array  $session
     * @return void
     */
    protected function _saveMessages( $messages, $session )
    {
      $success = array();
      foreach( $messages as $key => $message )
      {
        //Save chat data
        $chatData = array
        (
          'user_id'             => $session['user_id'],
          'sess_id'             => $session['sess_id'],
          'chat_timestamp'      => date( 'c' ),
          'chat_timestamp_gmt'  => gmdate( 'c' ),
          'chat_key'            => md5( $session['user_id'] . $session['sess_id'] . time() ),
          'chat_message'        => $message,
          'chat_status'         => 1,
          'chat_originates'     => 2
        );
        $result = $modChat->insertChat( $chatData );
        if ( $result ) {
          $success[$key] = $result;
        }
      }
      return $success;
    }

    //}}
    //{{ _saveUserStatus

    /**
     * Save user status
     *
     * @param  array  $session
     * @param  array  $user
     * @return void
     */
    protected function _saveUserStatus( $session, $user )
    {
      $toUpdate = array(
        'sess_last_active'      => date( 'c' ),
        'sess_last_active_gmt'  => gmdate( 'c' )
      );
      $modSession = new IPCht_Model_Session();
      $result = $modSession->updateSession( $session['sess_id'], $toUpdate );
    }

    //}}

  }
}
