<?php
/**
 * Class helper for create admin page
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Admin' )) 
{
	class IPCht_Admin extends IPCht_Form
	{
		//{{ parameters

		/**
		 * Take post setting
		 *
		 * @var array
		 */
		protected $_settings;

		/**
		 * Take view path
		 *
		 * @var string
		 */
		protected $_viewPath;
		
		/**
		 * Take config object
		 *
		 * @access protected
		 * @var array
		 */
		protected $_config;

		/**
		 * Take request ID
		 *
		 * @var string
		 */
		public $requestID;

		//}}
		//{{ __construct

		/**
		 * Class construct
		 *
		 * @param array $config
		 * @return void
		 */
		public function __construct( $config = array() )
		{
			$this->_settings = $config;
			$this->_viewPath = IPCHT_VIEW;
			$this->_setConfig( $config );

			//General pre process
			$this->_preProcess();
		}

		//}}
		//{{ render

		/**
		 * Render admin page
		 *
		 * @return void
		 */
		public function render()
		{
			echo $this->build();
		}

		//}}
		//{{ build

		/**
		 * Build admin page
		 *
		 * @return void
		 */
		public function build()
		{
			$this->_setViewData();
			$this->view( 'container' );
		}

		//}}
		//{{ header

		/**
		 * Build header admin page
		 *
		 * @return void
		 */
		public function header()
		{
			$this->_setNavStructure();
			$this->view( 'header' );
		}

		//}}
		//{{ pageMessage

		/**
		 * Build message in top of page
		 *
		 * @return void
		 */
		public function pageMessage()
		{
		}

		//}}
		//{{ topButtonAction

		/**
		 * Build button actions in top of page
		 *
		 * @return void
		 */
		public function topButtonActions()
		{
		}

		//}}
		//{{ main

		/**
		 * Main content
		 *
		 * @return void
		 */
		public function main()
		{
		}

		//}}
		//{{ view

		/**
		 * Get admin view file
		 *
		 * @param string $filename
		 * @return void
		 */
		public function view( $filename, $type = 'system' )
		{
			$path  = $this->_viewPath;
			if ( $type == 'admin' ) {
				$path .= 'admin/';
			} else {
				$path .= 'admin/system/';
			}
			$path .= strtolower( $filename ) . '.php';
			if ( file_exists( $path )) {
				include( $path );
			}
		}

		//}}
		//{{ config
		
		/**
		 * Get config object
		 *
		 * @return IPCht_Config
		 */
	  public function config()
		{
			return $this->_config;
		}

		//}}
		//{{ _setConfig
		
		/**
		 * _setConfig
		 *
		 * @param array $config
		 * @return void
		 */
	  protected function _setConfig( $config = array() )
		{
			$this->_config = new IPCht_Config( $config );
		}

		//}}
		//{{ _setViewData

		/**
		 * Set view data
		 *
		 * @return void
		 */
		protected function _setViewData()
		{
			$this->htmlRootID = 'ipcht-admin';
		}

		//}}
		//{{ _preProcess
		
		/**
		 * Pre processing request
		 *
		 * @return void
		 */
	  protected function _preProcess()
		{
		}

		//}}
		//{{ _setNavStructure

		/**
		 * Set navigation structure
		 *
		 * @return void
		 */
		protected function _setNavStructure()
		{
			$pageDash    = IPCHT_PAGENAME;
			$pageChat    = IPCHT_PAGENAME . '-chat';
			$pageOffline = IPCHT_PAGENAME . '-offline';
			$pageWidget  = IPCHT_PAGENAME . '-widget';
			$pageUser    = IPCHT_PAGENAME . '-user';
			$pageSetting = IPCHT_PAGENAME . '-setting';
			$struct 		 = array(
		    $pageDash => array(
          'title'     => __( 'Dashboard', IPCHT_SLUG ),
          'info'      => IPCHT_TITLE . ' ' . __( 'dashboard', IPCHT_SLUG ),
          'icon'      => 'format-chat'
		     ),
		    $pageChat 		=> array(
          'title'     => __( 'Chat', IPCHT_SLUG ),
          'info'      => __( 'See and manage all chat', IPCHT_SLUG ),
          'icon'      => 'admin-comments'
		     ),
		    $pageOffline 		=> array(
          'title'     => __( 'Offline Message', IPCHT_SLUG ),
          'info'      => __( 'See and manage all offline messages', IPCHT_SLUG ),
          'icon'      => 'email-alt'
		     ),
		    $pageUser => array(
          'title'     => __( 'Users', IPCHT_SLUG ),
          'info'      => __( 'Manage all users', IPCHT_SLUG ),
          'icon'      => 'admin-users'
		     ),
		    $pageWidget => array(
          'title'     => __( 'Widget', IPCHT_SLUG ),
          'info'      => __( 'Manage all chat widget styles', IPCHT_SLUG ),
          'icon'      => 'admin-customizer'
		     ),
		    $pageSetting => array(
          'title'     => __( 'Settings', IPCHT_SLUG ),
          'info'      => __( 'Manage general chat settings', IPCHT_SLUG ),
          'icon'      => 'admin-generic'
		     )
			 );
			$this->navStructure = $struct;
		}

		//
		//
		//Helper
		//

		//}}
		//{{ htmlMessage

		/**
		 * Build html message
		 *
		 * @param  string  $message
		 * @param  string  $type
		 * @return void
		 */
		public function htmlMessage( $message, $type = 'success' )
		{
			$msg = '<div class="ipcht-alert ipcht-alert-' . $type . '" style="display: block;">' .
								__( $message, IPCHT_SLUG ) .
							'</div>';

			echo $msg;
		}

		//}}
		//{{ htmlButtonAdd

		/**
		 * Build html message
		 *
		 * @param  string  $label
		 * @param  string  $page
		 * @param  string  $action
		 * @return void
		 */
		public function htmlButtonAdd( $label, $page, $action )
		{
			$link   = admin_url() . 'admin.php?page=' . $page . '&action=' . $action;
			$button = '<div class="_add-button mb30">' .
									'<a href="' . $link . '" class="ipcht-btn ipcht-btn-success ipcht-btn-sm _add-page">' .
										'<i class="ipcht-fa ipcht-fa-plus-circle"></i>' . 
										__( $label, IPCHT_SLUG ) .
									'</a>' .
								'</div>';

			echo $button;
		}

		//}}
	}
}