<?php
/**
 * Class helper for create admin page
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Admin_Manage' )) 
{
  class IPCht_Admin_Manage extends IPCht_Admin
  {
  	//{{ parameters

		/**
		 * Take object
		 *
		 * @var object
		 */
		public $object = false;

		/**
		 * Is dashboard page?
		 *
		 * @var boolean
		 */
		public $isDashboard = false;

		/**
		 * Is edit page?
		 *
		 * @var boolean
		 */
		public $isEdit = false;

		/**
		 * Is create page?
		 *
		 * @var boolean
		 */
		public $isCreate = false;

		/**
		 * Take setting name
		 *
		 * @var string
		 */
		protected $_settingName;

		/**
		 * Take root page ID
		 *
		 * @var string
		 */
		protected $_rootPageID;

		/**
		 * Take action name
		 *
		 * @var string
		 */
		protected $_actionName;

		//}}
		//{{ __construct

		/**
		 * Class construct
		 *
		 * @param array $config
		 * @return void
		 */
		public function __construct( $config = array() )
		{
			parent::__construct( $config );

			//Check page
			$this->_checkPage();
		}

		//}}
		//{{ build

		/**
		 * Build admin page
		 *
		 * @return void
		 */
		public function build()
		{
			parent::_setViewData();
			
      //Edit page
      if ( $this->isEdit )
      {
      	$this->_getObject();
      	$this->manage();
      }
	    //Creating page
	    elseif ( $this->isCreate )
	    {
	    	$this->manage();
	    }
      //Dashboard page
      else {
        $this->dashboard();
      }
		}

		//}}
		//{{ main

		/**
		 * Main content
		 *
		 * @return void
		 */
		public function main()
		{
			//Edit or create page
      if ( $this->isEdit || $this->isCreate )
      {
      	$this->view( 'content-manage' );
	    }
      //Dashboard page
      else 
      {
        if ( $list = $this->_getListObject() ) {
        	$list->render();
        }
      }
		}

		//
		//{{ manage

		/**
		 * Admin main manage page
		 *
		 * @return void
		 */
		public function manage()
		{
      //
      //Including script
      wp_enqueue_media();
      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

			$this->_setManageData();
			$this->view( 'container' );
		}

		//
		//{{ dashboard

		/**
		 * Admin dashboard page
		 *
		 * @return void
		 */
		public function dashboard()
		{
			$this->_setDashboardData();
			$this->view( 'container' );
		}

		//
		//{{ navManage

		/**
		 * Build navigation for manage page
		 *
		 * @return void
		 */
		public function navManage()
		{
			$this->_setNavManageStructure();
			$this->view( 'nav-manage' );
		}

		//
		//{{ afterNavManage

		/**
		 * After manage page hook
		 *
		 * @return void
		 */
		public function afterNavManage()
		{
		}

		//
		//{{ manageMain

		/**
		 * Build manage main content
		 *
		 * @return void
		 */
		public function manageMain()
		{
		}

		//}}
		//{{ _setDashboardData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setDashboardData()
		{
			$this->pageID    = $this->_rootPageID;
			$this->requestID = IPCHT_PAGENAME;
		}

		//}}
		//{{ _setManageData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setManageData()
		{
			//Set setting
			$id = 0;
      if ( $this->object ) {
        $id = $this->object->ID;
      }
      $this->_setSetting( $id );
      $this->objectId = $id;

      //Set main data
      $actionRoot = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipcht=1&action=';
      if ( $this->object )
      {
				$this->pageID 		 = $this->_rootPageID . '-edit';
				$this->formID 		 = $this->_rootPageID . '-edit-form';
				$this->submitID 	 = $this->_rootPageID . '-edit-submit';
				$this->deleteID 	 = $this->_rootPageID . '-delete';
        $this->submitIcon  = 'floppy-o';
        $this->submitLabel = __( 'Save Change', IPCHT_SLUG );

        //Header content
        $this->title = $this->getObjectTitle( $this->object );
        $this->info  =  '<i class="ipcht-fa ipcht-fa-calendar"></i> Created: ' .
            						'<strong>' . 
            							mysql2date( 'd F Y, h:i', $this->getObjectDate( $this->object ) ) .
            						'</strong>';
      }
      else
      {
				$this->pageID 		 = $this->_rootPageID . '-create';
				$this->formID 		 = $this->_rootPageID . '-create-form';
				$this->submitID 	 = $this->_rootPageID . '-create-submit';
        $this->submitIcon  = 'plus-circle';
        $this->submitLabel = __( 'Create', IPCHT_SLUG );
      }
      $this->formAction  = $actionRoot . $this->_actionName;

      $tab = 'ipcht-section-general';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;
		}

		//
		//{{ _setSetting

		/**
		 * Set manage setting data
		 *
		 * @return void
		 */
		public function _setSetting( $id )
		{
      $this->setting  = new IPCht_Setting( $id, $this->_settingName );
		}

		//
		//{{ _getObject

		/**
		 * Get object data
		 *
		 * @return void
		 */
		public function _getObject()
		{
			if ( empty( $_GET['id'] )) {
        wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPCHT_SLUG ) );
      }
      $id = absint( $_GET['id'] );
      if ( ! $object = get_post( $id ) ) {
        wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPCHT_SLUG ) );
      }
      $this->object = $object;
		}

		//
		//{{ _getListObject

		/**
		 * Get list object data
		 *
		 * @return void
		 */
		public function _getListObject()
		{
			return false;
		}

		//
		//{{ getObjectTitle

		/**
		 * Get object title
		 *
		 * @param object $object
		 * @return void
		 */
		public function getObjectTitle( $object )
		{
			return $object->post_title;
		}

		//
		//{{ getObjectDate

		/**
		 * Get object date
		 *
		 * @param object $object
		 * @return void
		 */
		public function getObjectDate( $object )
		{
			return $object->post_date;
		}

		//
		//{{ _checkPage

		/**
		 * Check page type
		 *
		 * @return void
		 */
		public function _checkPage()
		{
			if ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
      	$this->isEdit = true;
      }
	    //Creating page
	    elseif ( isset( $_GET['action'] ) && $_GET['action'] == 'create' ) {
      	$this->isCreate = true;
	    }
      //Dashboard page
      else {
      	$this->isDashboard = true;
      }
		}
  }
}