<?php
/**
 * Class helper for admin widget page
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Admin_Widget' )) 
{
  class IPCht_Admin_Widget extends IPCht_Admin_Manage
  {
		//{{ __construct

		/**
		 * Class construct
		 *
		 * @param array $config
		 * @return void
		 */
		public function __construct( $config = array() )
		{
			$this->_settingName = '__ipcht_widget_setting';
			$this->_rootPageID 	= 'ipcht-admin-widget';
			$this->_actionName 	= 'update_widget';

			parent::__construct( $config );
		}

		//}}
		//{{ pageMessage

		/**
		 * Build message in top of page
		 *
		 * @return void
		 */
		public function pageMessage()
		{
			//
			//Dashboard
			if ( $this->isDashboard )
			{
				if ( isset( $_GET['update'] )) 
				{
					$this->htmlMessage( 'Successfully updating widget settings.' );
				}
			}
		}

		//}}
		//{{ build

		/**
		 * Build admin page
		 *
		 * @return void
		 */
		public function build()
		{
			parent::_setViewData();

			$this->htmlRootID   = 'ipcht-admin-widget';
			$this->singleManage = true;
			
      //Edit page
      $this->manage();
		}

		//}}
		//{{ main

		/**
		 * Main content
		 *
		 * @return void
		 */
		public function main()
		{
			$this->view( 'content-manage' );
		}

		//
		//{{ manageMain

		/**
		 * Build manage main content
		 *
		 * @return void
		 */
		public function manageMain()
		{
			$this->manageGeneral();
			$this->manageTab();
			$this->manageHeader();
			$this->manageFooter();
			$this->manageArea();
			$this->manageInput();
			$this->manageChat();
			$this->manageEffect();
		}

		//
		//{{ manageGeneral

		/**
		 * Build manage general content
		 *
		 * @return void
		 */
		public function manageGeneral()
		{
			$this->tabId   		= 'ipcht-section-general';
			$this->tabTitle   = __( 'General', IPCHT_SLUG );
			$this->tabInfo    = __( 'Basic settings of your widget styles', IPCHT_SLUG );
			$this->tabIcon    = 'cogs';
			$this->tabView    = 'widget/field-general';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageTab

		/**
		 * Build manage tab content
		 *
		 * @return void
		 */
		public function manageTab()
		{
			$this->tabId   		= 'ipcht-section-tab';
			$this->tabTitle   = __( 'Tab', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the tab button', IPCHT_SLUG );
			$this->tabIcon    = 'cogs';
			$this->tabView    = 'widget/field-tab';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageHeader

		/**
		 * Build manage header content
		 *
		 * @return void
		 */
		public function manageHeader()
		{
			$this->tabId   		= 'ipcht-section-header';
			$this->tabTitle   = __( 'Header', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the header area of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'header';
			$this->tabView    = 'widget/field-header';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageFooter

		/**
		 * Build manage footer content
		 *
		 * @return void
		 */
		public function manageFooter()
		{
			$this->tabId   		= 'ipcht-section-footer';
			$this->tabTitle   = __( 'Footer', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the footer area of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'level-down';
			$this->tabView    = 'widget/field-footer';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageArea

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageArea()
		{
			$this->tabId   		= 'ipcht-section-area';
			$this->tabTitle   = __( 'Main Content', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the main content of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'square-o';
			$this->tabView    = 'widget/field-area';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageInput

		/**
		 * Build manage chat input
		 *
		 * @return void
		 */
		public function manageInput()
		{
			$this->tabId   		= 'ipcht-section-input';
			$this->tabTitle   = __( 'Form', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the chat form', IPCHT_SLUG );
			$this->tabIcon    = 'edit';
			$this->tabView    = 'widget/field-input';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageChat

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageChat()
		{
			$this->tabId   		= 'ipcht-section-chat';
			$this->tabTitle   = __( 'Chat Bubble', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the chat buble', IPCHT_SLUG );
			$this->tabIcon    = 'comment';
			$this->tabView    = 'widget/field-chat';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageEffect

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageEffect()
		{
			$this->tabId   		= 'ipcht-section-effect';
			$this->tabTitle   = __( 'Effect', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set the effect of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'magic';
			$this->tabView    = 'widget/field-effect';

			$this->view( 'tab-section' );
		}

		//}}
		//{{ _setManageData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setManageData()
		{
			parent::_setManageData();

			$this->formID 	   = $this->_rootPageID . '-form';
			$this->submitID 	 = $this->_rootPageID . '-save';
      $this->submitIcon  = 'floppy-o';
      $this->submitLabel = __( 'Save Change', IPCHT_SLUG );

			//
			//Set settings
      $model = new IPCht_Model_Widget();
      $this->setting = $model->getSettings();

			$this->requestID = IPCHT_PAGENAME . '-widget';
			$this->pageTitle = __( 'Widget', IPCHT_SLUG );

      //Tab default info
      $this->tabDefaultTitle = __( 'General', IPCHT_SLUG );
      $this->tabDefaultInfo  = __( 'Basic settings of your widget chat', IPCHT_SLUG );
      $this->tabDefaultIcon  = 'cogs';
		}

		//}}
		//{{ _setNavManageStructure

		/**
		 * Set navigation structure
		 *
		 * @return void
		 */
		protected function _setNavManageStructure()
		{
			$struct = array
			(
		    'ipcht-section-tab' => array(
          'title'     => 'Tab Button',
          'icon'      => 'plus-square'
		    ),
		    'ipcht-section-header' => array(
          'title'     => 'Header',
          'icon'      => 'header'
		    ),
		    'ipcht-section-footer' => array(
          'title'     => 'Footer',
          'icon'      => 'level-down'
		    ),
		    'ipcht-section-area' => array(
          'title'     => 'Main Content',
          'icon'      => 'square-o'
		    ),
		    'ipcht-section-chat' => array(
          'title'     => 'Chat Bubble',
          'icon'      => 'comment'
		    ),
		    'ipcht-section-input' => array(
          'title'     => 'Form',
          'icon'      => 'edit'
		    ),
		    'ipcht-section-effect' => array(
          'title'     => 'Effect',
          'icon'      => 'magic'
		    ),
			);
			$this->navManageStructure = $struct;
		}
  }
}