<?php
/**
 * Class helper for handling chat
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Chat' )) 
{
	class IPCht_Chat
	{
    //{{ getChats

    /**
     * Get chats from current sessions
     *
     * @return string
     */
    public static function getChats()
    {
      $chats = false;

      if ( $session = self::getSession() )
      {
        $modChat = new IPCht_Model_Chat();
        $chats   = $modChat->getChatsByUser( $session['user_id'] );
      }
      return $chats;
    }

    //}}
    //{{ getUserChats

    /**
     * Get chats from current sessions
     *
     * @return string
     */
    public static function getUserChats()
    {
      $modChat    = new IPCht_Model_Chat();
      $modSession = new IPCht_Model_Session();
      $result     = array();
      $users      = $modSession->getUserSessions();

      if ( $users )
      {
        $_users = array();
        foreach( $users as $user )
        {
          $userId = $user->user_id;
          if ( ! array_key_exists($userId, $_users)) {
            $_users[$userId] = $user;
          }
        }

        foreach( $_users as $user )
        {
          $chats = $modChat->getChatsByUser( $user->user_id );
          if ( empty( $chats )) {
            continue;
          }
          $_cht = $chats;
          $last = array_pop( $_cht );
          if ( strlen( $last->chat_message ) > 30 )
          {
            $chmsg  = stripslashes( $last->chat_message );
            $label  = substr( $chmsg, 0, 30 );
            $label .= '...';
          } 
          else {
            $label = stripslashes( nl2br( $last->chat_message ) );
          }

          if ( self::isUserOnline( $user ) ) {
            $online = 1;
          } else {
            $online = 0;
          }

          $data = array(
            'user'    => $user,
            'label'   => $label,
            'online'  => $online,
            'chats'   => $chats
          );
          $result[] = $data;
        }
      }
      return $result;
    }

    //}}
    //{{ saveOfflineMessage

    /**
     * Save offline message data
     *
     * @return string
     */
    public static function saveOfflineMessage()
    {
      $name    = '';
      $phone   = '';
      $email   = sanitize_email( $_POST['email'] );
      $message = apply_filters( 'single_post_title', $_POST['message'] );

      if ( isset( $_POST['name'] )) {
        $name = apply_filters( 'single_post_title', $_POST['name'] );
      }
      if ( isset( $_POST['phone'] )) {
        $phone = apply_filters( 'single_post_title', $_POST['phone'] );
      }

      $result = self::saveOfflineMessageData( $message, $email, $name, $phone );

      return $result;
    }

    //}}
    //{{ saveOfflineMessageUser

    /**
     * Save offline message data
     *
     * @param  string $message
     * @param  array  $user
     * @return string
     */
    public static function saveOfflineMessageUser( $message, $user )
    {
      $name    = $user['user_name'];
      $phone   = $user['user_phone'];
      $email   = $user['user_email'];
      $result  = self::saveOfflineMessageData( $message, $email, $name, $phone );

      return $result;
    }

    //}}
    //{{ saveOfflineMessageData

    /**
     * Save offline message data
     *
     * @param  string $message
     * @param  string $email
     * @param  string $name
     * @param  string $phone
     * @return string
     */
    public static function saveOfflineMessageData( $message, $email, $name = '', $phone = '' )
    {
      $result = false;

      //Save message
      $toInsert = array(
        'choff_user_name'       => $name,
        'choff_user_email'      => $email,
        'choff_user_phone'      => $phone,
        'choff_message'         => $message,
        'choff_timestamp'       => date( 'c' ),
        'choff_timestamp_gmt'   => date( 'c' ),
        'choff_key'             => md5( time() . $_SERVER['REMOTE_ADDR'] ),
        'choff_ip'              => $_SERVER['REMOTE_ADDR'],
        'choff_user_agent'      => $_SERVER['HTTP_USER_AGENT'],
        'choff_status'          => 0,
      );

      $model  = new IPCht_Model_ChatOffline();
      $result = $model->insertChat( $toInsert );

      return $result;
    }

    //}}
    //{{ createAdminChats

    /**
     * Get chat items from admin
     *
     * @param  array $session
     * @return string
     */
    public static function createAdminChats( $session )
    {
      //Check excludes
      $excludes = array();
      if ( ! empty( $_POST['last_chats'] ))
      {
        $excludes = explode( ',', $_POST['last_chats'] );
      }

      //Check date
      $date = null;
      if ( ! empty( $_POST['last_date'] ))
      {
        $lastDate = apply_filters( 'single_post_title', $_POST['last_date'] );
        $strtime  = strtotime( $lastDate );
        $date     = date( 'Y-m-d h:i:s', $strtime );
      }
      $modChat = new IPCht_Model_Chat();
      $chats   = $modChat->getChatsByAdmin( $session['user_id'], $date );

      $html = '';
      $ids  = '';
      $chld = '0';
      if ( ! empty( $chats ))
      {
        foreach( $chats as $chat )
        {
          $chat  = (array)$chat;

          if ( in_array( $chat['chat_id'], $excludes )) {
            continue;
          }
          $html .= self::createChat( $chat );
          $ids  .= $chat['chat_id'] . '|';
          $chld  = mysql2date( 'd-m-Y h:i:s', $chat['chat_timestamp_gmt'] );
        }
      }
      $ids = trim( $ids, '|' );
      return array(
        'html'      => $html,
        'ids'       => $ids,
        'last_date' => $chld
      );
    }

    //}}
    //{{ createUserChats

    /**
     * Get chat items from admin
     *
     * @param  array $session
     * @return string
     */
    public static function createUserChats( $session )
    {
      //Check date
      $date = null;
      if ( ! empty( $_POST['last_date'] ))
      {
        $lastDate = apply_filters( 'single_post_title', $_POST['last_date'] );
        $strtime  = strtotime( $lastDate );
        $date     = date( 'Y-m-d h:i:s', $strtime );
      }

      $modChat = new IPCht_Model_Chat();
      $chats   = $modChat->getChatsByUserDate( $session['user_id'], $date );

      $html = '';
      $chld = '0';
      if ( ! empty( $chats ))
      {
        foreach( $chats as $chat )
        {
          $chat  = (array)$chat;
          $html .= self::createChat( $chat );
          $chld  = mysql2date( 'd-m-Y h:i:s', $chat['chat_timestamp_gmt'] );
        }
      }
      return array(
        'html'      => $html,
        'last_date' => $chld
      );
    }

    //}}
    //{{ createChats

    /**
     * Create chat item
     *
     * @param  array $session
     * @return string
     */
    public static function createChats( $session )
    {
      $modChat = new IPCht_Model_Chat();
      $chats   = $modChat->getChatsByUser( $session['user_id'] );

      $result  = '';
      if ( ! empty( $chats ))
      {
        foreach( $chats as $chat )
        {
          $chat    = (array)$chat;
          $result .= self::createChat( $chat );
        }
      }
      return $result;
    }

    //}}
    //{{ createBackendChats

    /**
     * Create chat item
     *
     * @param  array $session
     * @return string
     */
    public static function createBackendChats( $session )
    {
      $modChat = new IPCht_Model_Chat();
      $chats   = $modChat->getChatsByUser( $session['user_id'] );

      $html  = '';
      $chld  = '0';
      if ( ! empty( $chats ))
      {
        foreach( $chats as $chat )
        {
          $chat  = (array)$chat;
          $html .= self::createChat( $chat );
          $chld  = mysql2date( 'd-m-Y h:i:s', $chat['chat_timestamp_gmt'] );
        }
      }
      return array(
        'html'      => $html,
        'last_date' => $chld
      );
    }

    //}}
    //{{ createChat

    /**
     * Create chat item
     *
     * @param  array $data
     * @return string
     */
    public static function createChat( $data )
    {
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      //Class
      $class   = 'ipcht-chat-item ipcht-clearfix';
      if ( $data['chat_originates'] == 2 ) {
        $class .= ' ipcht-chat-user';
      } else {
        $class .= ' ipcht-chat-admin';
      }
      $result  = '<div class="' . $class . '">';
      $result .= '<div class="ipcht-chat-inner ipcht-clearfix">';
      
      //User Icon
      $color     = self::getIconColor( $data );
      $result   .= '<div class="ipcht-chat-icon ipcht-chat-icon-alpha" style="background-color:' . $color . '">';

      //Get username
      if ( $data['chat_originates'] == 2 ) {
        $username = $data['user_name'];
      } else {
        $username = $system->getSetting( 'admin_name', get_option( 'blogname' ) );
      }

      //Get user photo
      $userphoto = false;
      $photoId   = 0;
      if ( $data['chat_originates'] == 2 ) {
        $photoId = $system->getSetting( 'user_photo' );
      } else {
        $photoId = $system->getSetting( 'admin_photo' );
      }
      if ( ! empty( $photoId ))
      {
        $phdata = wp_get_attachment_image_src( $photoId, 'full' );
        if ( ! empty( $phdata[0] )) {
          $userphoto = $phdata[0];
        }
      }

      $thumbType = $system->getSetting( 'user_photo_type', 'name' );
      if ( $thumbType == 'name' ) {
        $result .= substr( $username, 0, 1 );
      }
      elseif ( $thumbType == 'photo' && $userphoto ) {
        $result .= '<img class="ipcht-user-photo" src="' . $userphoto . '" alt="">';
      }
      $result   .= '</div>';

      //Main
      $result .= '<div class="ipcht-chat-bubble">';
      $result .= '<div class="ipcht-chat-bubble-inner">';

      //Top
      $result .= '<div class="ipcht-chat-top">';
      
      $result .= '<div class="ipcht-chat-user">';
      $result .= '<strong>' . $username . '</strong>';
      $result .= '</div>';

      $result .= '<div class="ipcht-chat-date">';
      $result .= mysql2date( 'd/m h:m', $data['chat_timestamp'] );
      $result .= '<span class="ipcht-chat-status ipcht-chat-status-delivered">';
      $result .= '<i class="ipcht-fa ipcht-fa-clock-o"></i>';
      $result .= '<i class="ipcht-fa ipcht-fa-check"></i>';
      $result .= '</span>';
      $result .= '</div>';

      $result .= '</div>';

      //Message
      $result .= '<div class="ipcht-chat-message">';
      $result .= stripslashes( nl2br( $data['chat_message'] ) );
      $result .= '</div>';

      //End Main
      $result .= '</div>';
      $result .= '</div>';

      //End container
      $result .= '</div>';
      $result .= '</div>';

      return $result;
    }

    //}}
    //{{ getIconColor

    /**
     * Get icon color
     *
     * @return string
     */
    public static function getIconColor( $data )
    {
      $colors = array(
        '#666666',
        '#336eb8',
        '#3da7c6',
        '#33a746',
        '#c14127',
        '#ce6e3a',
        '#ada458',
        '#b55a94',
        '#824b9b',
        '#4e429a',
        '#569f84',
        '#8ba955'
      );

      if ( isset( $_POST['color'] ) && ! empty( $_POST['color'] ))
      {
        $color = apply_filters( 'single_post_title', $_POST['color'] );
      }
      else if ( ( isset( $_POST['user_color'] ) && ! empty( $_POST['user_color'] ) ) &&
                ( isset( $_POST['admin_color'] ) && ! empty( $_POST['admin_color'] ) )
      ) {
        if ( $data['chat_originates'] == 2 ) {
          $color = apply_filters( 'single_post_title', $_POST['user_color'] );
        } else {
          $color = apply_filters( 'single_post_title', $_POST['admin_color'] );
        }
      }
      else
      {
        $rand = rand( 0, 11 );
        $color = $colors[$rand];
      }
      return $color;
    }

    //}}
    //{{ isOnline

    /**
     * Check admin is online?
     *
     * @return string
     */
    public static function isOnline()
    {
      $status = get_option( '__ipcht_admin_online_status' );
      $time   = get_option( '__ipcht_admin_online_time' );

      if ( $time && $status && $status == 1 ) 
      {
        $now = time();
        if ( $now > $time + 5 ) {
          return false;
        }
        return true;
      }
      return false;
    }

    //}}
    //{{ isOffline

    /**
     * Check admin is offline?
     *
     * @return string
     */
    public static function isOffline()
    {
      return ! self::isOnline();
    }

    //}}
    //{{ isLogin

    /**
     * Check user is login?
     *
     * @return array
     */
    public static function isLogin()
    {
      $session = self::getSession();
      return $session;
    }

    //}}
    //{{ isUserOnline

    /**
     * Check admin is online?
     *
     * @param  array $user
     * @return string
     */
    public static function isUserOnline( $user )
    {
      $user = (array)$user;
      $time = $user['sess_last_active_gmt'];

      if ( ! empty( $time ) ) 
      {
        $time = strtotime( $time );
        $now  = time();
        if ( $now > $time + 5 ) {
          return false;
        }
        return true;
      }
      return false;
    }

    //}}
    //{{ isUserOffline

    /**
     * Check admin is offline?
     *
     * @param  array $user
     * @return string
     */
    public static function isUserOffline( $user )
    {
      return ! self::isUserOnline( $user );
    }

    //}}
    //{{ getSession

    /**
     * Check user is login?
     *
     * @return string
     */
    public static function getSession()
    {
      $session = false;
      if ( isset( $_COOKIE['__ipcht_chat_session'] ) && ! empty( $_COOKIE['__ipcht_chat_session'] ))
      {
        $sessKey    = apply_filters( 'single_post_title', $_COOKIE['__ipcht_chat_session'] );
        $modSession = new IPCht_Model_Session();
        $session    = $modSession->getSessionByKey( $sessKey );
      }
      return $session;
    }

    //}}
    //{{ sendNotifNewChat

    /**
     * Sending notification if any offline message
     *
     * @param  array  $user
     * @param  string $chat
     * @return void
     */
    public static function sendNotifNewChat( $user, $chat )
    {
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      $adminTitle = get_option( 'blogname' );
      $adminEmail = get_option( 'admin_email' );
      $email      = $system->getSetting( 'notif_email', $adminEmail );
      $active     = $system->getSetting( 'notif_chat', 'false' );

      if ( $active == 'true' )
      {
        //Subject
        $subject   = __( 'New Chat' ) . ' on ' . $adminTitle;
        //Message content
        $content   = __( 'You have to get the new chat on your website with the details as follows:<br/>', IPCHT_SLUG );
        if ( ! empty( $user['user_name'] )) {
          $content  .= __( 'Name:', IPCHT_SLUG ) . ' ' . $user['user_name'] . '<br/>';
        }
        $content  .= __( 'Email:', IPCHT_SLUG ) . ' ' . $user['user_email'] . '<br/>';
        if ( ! empty( $user['user_phone'] )) {
          $content  .= __( 'Phone:', IPCHT_SLUG ) . ' ' . $user['user_phone'] . '<br/>';
        }
        $content  .= __( 'Message:', IPCHT_SLUG ) . ' ' . $chat;
        //Headers
        $headers[] = 'Content-Type: text/html; charset=UTF-8';

        @wp_mail( $email, $subject, $content, $headers );
      }

    }

    //}}
    //{{ sendNotifOfflineMsg

    /**
     * Sending notification if any offline message
     *
     * @return string
     */
    public static function sendNotifOfflineMsg()
    {
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      $name    = '';
      $phone   = '';
      $email   = sanitize_email( $_POST['email'] );
      $message = apply_filters( 'single_post_title', $_POST['message'] );

      if ( isset( $_POST['name'] )) {
        $name = apply_filters( 'single_post_title', $_POST['name'] );
      }
      if ( isset( $_POST['phone'] )) {
        $phone = apply_filters( 'single_post_title', $_POST['phone'] );
      }

      $adminTitle = get_option( 'blogname' );
      $adminEmail = get_option( 'admin_email' );
      $email      = $system->getSetting( 'notif_email', $adminEmail );
      $active     = $system->getSetting( 'notif_chat_offline', 'true' );

      if ( $active == 'true' )
      {
        //Subject
        $subject   = __( 'New Offline Message' ) . ' on ' . $adminTitle;
        //Message content
        $content   = __( 'You have to get the message offline on your website with the details as follows:<br/>', IPCHT_SLUG );
        if ( ! empty( $name )) {
          $content  .= __( 'Name:', IPCHT_SLUG ) . ' ' . $name . '<br/>';
        }
        $content  .= __( 'Email:', IPCHT_SLUG ) . ' ' . $email . '<br/>';
        if ( ! empty( $phone )) {
          $content  .= __( 'Phone:', IPCHT_SLUG ) . ' ' . $phone . '<br/>';
        }
        $content  .= __( 'Message:', IPCHT_SLUG ) . ' ' . $message;
        //Headers
        $from = 'From: ';
        if ( ! empty( $name )) {
          $from .= $name;
        } else {
          $from .= $email;
        }
        $from = ' <' . $email . '>';

        $headers[] = $from;
        $headers[] = 'Content-Type: text/html; charset=UTF-8';

        @wp_mail( $email, $subject, $content, $headers );
      }

    }

    //}}
    //{{ sendNotifOfflineMsgUser

    /**
     * Sending notification if any offline message
     *
     * @param  array  $user
     * @param  string $message
     * @return string
     */
    public static function sendNotifOfflineMsgUser( $user, $message )
    {
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      $name      = '';
      $phone     = '';
      $userEmail = $user['user_email'];

      if ( isset( $user['user_name'] )) {
        $name = $user['user_name'];
      }
      if ( isset( $user['user_phone'] )) {
        $phone = $user['user_phone'];
      }

      $adminTitle = get_option( 'blogname' );
      $adminEmail = get_option( 'admin_email' );
      $email      = $system->getSetting( 'notif_email', $adminEmail );
      $active     = $system->getSetting( 'notif_chat_offline', 'true' );

      if ( $active == 'true' )
      {
        //Subject
        $subject   = __( 'New Offline Message' ) . ' on ' . $adminTitle;
        //Message content
        $content   = __( 'You have to get the message offline on your website with the details as follows:<br/>', IPCHT_SLUG );
        if ( ! empty( $name )) {
          $content  .= __( 'Name:', IPCHT_SLUG ) . ' ' . $name . '<br/>';
        }
        $content  .= __( 'Email:', IPCHT_SLUG ) . ' ' . $userEmail . '<br/>';
        if ( ! empty( $phone )) {
          $content  .= __( 'Phone:', IPCHT_SLUG ) . ' ' . $phone . '<br/>';
        }
        $content  .= __( 'Message:', IPCHT_SLUG ) . ' ' . $message;
        //Headers
        $from = 'From: ';
        if ( ! empty( $name )) {
          $from .= $name;
        } else {
          $from .= $userEmail;
        }
        $from = ' <' . $userEmail . '>';

        $headers[] = $from;
        $headers[] = 'Content-Type: text/html; charset=UTF-8';

        @wp_mail( $email, $subject, $content, $headers );
      }

    }

    //}}
	}
}