<?php
/**
 * Class helper for create form
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Form' )) 
{
  class IPCht_Form
  {
    //{{ input

    /**
     * Build form input
     *
     * @param string $name
     * @param string $type
     * @param string $value
     * @param array  $atts
     *
     * @return IPCht_Html
     */
    public function input( 
      $name, $type = 'text', $value = '', $atts = array()
    )
    {
      if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
      {
        $value = $this->setting->getSetting( $name, $value );
      }
      $value = stripslashes( $value );
      $defaultAtts = array(
        'type'  => $type,
        'value' => $value,
        'id'    => 'input-' . $name,
        'name'  => $name,
        'class' => 'ipcht-input ipcht-input-full'
      );

      if ( ! empty( $atts )) {
        $defaultAtts = array_merge( $defaultAtts, $atts );
      }

      $input = new IPCht_Html( 'input', '', $defaultAtts );
      return $input;
    }

    //}}
    //{{ renderInput

    /**
     * Render form input
     *
     * @param string $name
     * @param string $type
     * @param string $value
     * @param array  $atts
     *
     * @return void
     */
    public function renderInput( 
      $name, $type = 'text', $value = '', $atts = array()
    ) {
      $html = $this->input( $name, $type, $value, $atts );
      echo $html->create();
    }

    //}}
  	//{{ inputSize

  	/**
  	 * Build form input size
  	 *
  	 * @param string $name
     * @param string $value
  	 * @param string $unit
  	 *
  	 * @return IPCht_Html
  	 */
  	public function inputSize( 
  		$name, $value = '', $unit = 'px'
  	)
  	{
  		if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
  		{
  			$value = $this->setting->getSetting( $name, $value );
  		}
  		$atts = array(
  			'type'	=> 'text',
  			'value' => $value,
  			'id'		=> 'input-' . $name,
  			'name'	=> $name,
  			'class' => 'ipcht-input ipcht-input-xs'
  		);

      $input = new IPCht_Html( 'input', '', $atts );
      $unit  = new IPCht_Html( 'div', $unit, array(
        'class'   => 'ipcht-input-addon'
      ));

      $group = new IPCht_Html( 'div', array(
        $input,
        $unit
      ), array(
        'class'   => 'ipcht-input-group mr5'
      ));

  		return $group;
  	}

  	//}}
  	//{{ renderInputSize

  	/**
  	 * Render form input size
  	 *
     * @param string $name
     * @param string $value
     * @param string $unit
  	 *
  	 * @return void
  	 */
  	public function renderInputSize( 
  		$name, $value = '', $unit = 'px'
  	) {
  		$html = $this->input( $name, $type, $value, $atts );
  		echo $html->create();
  	}

    //}}
    //{{ textarea

    /**
     * Build form textarea
     *
     * @param string $name
     * @param string $value
     * @param array  $atts
     *
     * @return IPCht_Html
     */
    public function textarea( 
      $name, $value = '', $atts = array()
    )
    {
      if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
      {
        $value = $this->setting->getSetting( $name, $value );
      }
      $value = stripslashes( $value );
      $defaultAtts = array(
        'id'    => 'input-' . $name,
        'name'  => $name,
        'class' => 'ipcht-input ipcht-input-full'
      );

      if ( ! empty( $atts )) {
        $defaultAtts = array_merge( $defaultAtts, $atts );
      }

      $input = new IPCht_Html( 'textarea', $value, $defaultAtts );
      return $input;
    }

    //}}
    //{{ renderTextarea

    /**
     * Render form textarea
     *
     * @param string $name
     * @param string $value
     * @param array  $atts
     *
     * @return void
     */
    public function renderTextarea( 
      $name, $value = '', $atts = array()
    ) {
      $html = $this->textarea( $name, $value, $atts );
      echo $html->create();
    }

    //}}
    //{{ select

    /**
     * Build form select
     *
     * @param string $name
     * @param array  $options
     * @param string $value
     * @param array  $atts
     *
     * @return IPCht_Html
     */
    public function select( 
      $name, $options, $value = '', $atts = array()
    )
    {
      if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
      {
        $value = $this->setting->getSetting( $name, $value );
      }
      $defaultAtts = array(
        'id'    => 'input-' . $name,
        'name'  => $name,
        'class' => 'ipcht-input'
      );

      if ( ! empty( $atts )) {
        $defaultAtts = array_merge( $defaultAtts, $atts );
      }

      $content = '';
      if ( is_array( $options )) 
      {
        foreach( $options as $key => $label )
        {
          $sltd = '';
          if ( $key == $value ) {
              $sltd = ' selected="selected"';
          }
          $content .= '<option value="' . $key . '"' . $sltd . '>' . $label . '</option>';
        }
      }

      $input = new IPCht_Html( 'select', $content, $defaultAtts );
      return $input;
    }

    //}}
    //{{ renderSelect

    /**
     * Render form select
     *
     * @param string $name
     * @param array  $options
     * @param string $value
     * @param array  $atts
     *
     * @return void
     */
    public function renderSelect( 
      $name, $options, $value = '', $atts = array()
    ) {
      $html = $this->select( $name, $options, $value, $atts );
      echo $html->create();
    }

    //}}
    //{{ fancyOption

    /**
     * Build form fancy option
     *
     * @param string $name
     * @param string $value
     *
     * @return IPCht_Html
     */
    public function fancyOption( $name, $value = '' )
    {
      //Check font class
      if ( ! class_exists( 'IPCht_Font' )) {
        return false;
      }
      //Get value
      if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
      {
        $value = $this->setting->getSetting( $name, $value );
      }

      $fonts   = IPCht_Font::getOptions();
      $fname   = IPCht_Font::getFontName( $value );

      $control = '<div class="ipcht-menu">' .
                    '<div class="ipcht-selected">' .
                      '<div class="ipcht-selected-box">' .
                        '<span data-select="' . $value . '">' .
                          $fname . 
                        '</span>' .
                      '</div>' .
                      '<span class="toggle"></span>' . 
                    '</div>' .
                    '<div class="ipcht-select" style="display: none;">' .
                      '<div class="ipcht-select-content">' .
                        '<ul class="clearfix">';

      foreach( $fonts as $fkey => $label ) 
      {
        $control .= '<li data-select="' . $fkey . '">' .
                      '<strong class="ipcht-select-label">' . $label . '</strong>' .
                    '</li>';
      }
      $control .=       '</ul>' .
                      '</div>' .
                    '</div>' .
                    '<input type="hidden" name="' . $name . '" class="ipcht-input-select" value="' . $value . '" />' .
                  '</div>';

      $input = new IPCht_Html( 'div', $control, array(
        'class' => 'ipcht-fancy-option'
      ));
      return $input;
    }

    //}}
    //{{ renderFancyOption

    /**
     * Render form fancy option
     *
     * @param string $name
     * @param string $value
     *
     * @return void
     */
    public function renderFancyOption( $name, $value = '' )
    {
      $html = $this->fancyOption( $name, $options, $value, $atts );
      echo $html->create();
    }

    //}}
    //{{ onOff

    /**
     * Build form on off buttons
     *
     * @param string $name
     * @param string $value
     * @param string $labelOn
     * @param string $labelOff
     *
     * @return IPCht_Html
     */
    public function onOff( 
      $name, $value = '', $labelOn = 'On', $labelOff = 'Off'
    )
    {
      if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
      {
        $value = $this->setting->getSetting( $name, $value );
      }

      if ( $value == 'false' ) {
          $clon  = '';
          $cloff = ' active';
      } else {
          $clon  = ' active';
          $cloff = '';
      }

      $control = '<div class="ipcht-btn-group">' .
                    '<button data-value="true" class="ipcht-btn-onoff ipcht-btn-on' . $clon . '" type="button">' .
                        __( $labelOn, IPCHT_SLUG ) .
                    '</button>' .
                    '<button data-value="false" class="ipcht-btn-onoff ipcht-btn-off' . $cloff . '" type="button">' .
                      __( $labelOff, IPCHT_SLUG ) . 
                    '</button>' .
                  '</div>' .
                  '<input type="hidden" class="ipcht-onoff-value" name="' . $name . '" value="' . $value . '"/>';

      $input = new IPCht_Html( 'div', $control, array(
        'class' => 'ipcht-onoff'
      ));
      return $input;
    }

    //}}
    //{{ renderOnOff

    /**
     * Render On Off buttons
     *
     * @param string $name
     * @param string $value
     * @param string $labelOn
     * @param string $labelOff
     * @param IPCht_Config $config
     *
     * @return void
     */
    public function renderOnOff( 
      $name, $value = '', $labelOn = 'On', $labelOff = 'Off'
    ) {
      $html = $this->onOff( $name, $value, $labelOn, $labelOff );
      echo $html->create();
    }

  	//}}
  	//{{ image

  	/**
  	 * Build form input image
  	 *
  	 * @param string $name
  	 *
  	 * @return IPCht_Html
  	 */
  	public function image( $name )
    {
      $setimg   = false;
      $attachId = 0;
  		if ( isset( $this->setting ) && $this->setting && $this->setting instanceof IPCht_Config )
  		{
  			$attachId = $this->setting->getSetting( $name );
        if ( $attachId ) {
          $setimg = true;
          $data   = wp_get_attachment_image_src( $attachId, 'thumbnail' );
        }
  		}

      //Preview
  		$control = '<div class="ipcht-upload-preview">';
      if ( $setimg ) {
          $control .= '<div class="image"><img src="' . $data[0] . '" /></div>';
          $control .='<div class="none ipcht-hide">' . __( 'No image', IPCHT_SLUG ) . '</div>';
          $resetDsp = '';
      } else {
          $control .='<div class="image"></div>';
          $control .='<div class="none">' . __( 'No image', IPCHT_SLUG ) . '</div>';
          $resetDsp = ' style="display:none;"';
      }
      $control .= '</div>';
      $control .= '<div class="ipcht-image-field">' . 
                    '<div class="ipcht-select-image">' .
                      '<p class="mt0">' .
                          __( 'Select an image or upload new image using the button below.', IPCHT_SLUG ) .
                      '</p>' .
                      '<a class="ipcht-btn ipcht-btn-secondary ipcht-btn-media ipcht-btn-sm"' .
                          'data-choose="' . __( 'Choose Image', IPCHT_SLUG ) . '"' . 
                          'data-update="' . __( 'Choose image', IPCHT_SLUG ) . '">' .
                        '<i class="ipcht-fa ipcht-fa-image"></i>' .
                        __( 'Select Image', IPCHT_SLUG ) . 
                      '</a>' .
                      '<a class="ipcht-btn ipcht-btn-reset ipcht-btn-sm ml5" href="#"' . $resetDsp . '>' .
                          '<i class="ipcht-fa ipcht-fa-ban"></i>' .
                          __( 'Clear Image', IPCHT_SLUG ) .
                      '</a>' .
                    '</div>' .
                    '<input type="hidden" name="upload_type" class="ipcht-upload-type" value="' . $name . '" />' .
                    '<input type="hidden" name="' . $name . '" class="ipcht-image-id" value="' . $attachId . '" />' .
                  '</div>';

  		$input = new IPCht_Html( 'div', $control, array(
        'class' => 'ipcht-upload-image ipcht-clear'
      ));
  		return $input;
  	}

  	//}}
  	//{{ renderImage

  	/**
  	 * Render input image
  	 *
  	 * @param string $name
  	 *
  	 * @return void
  	 */
  	public function renderImage( $name ) 
    {
  		$html = $this->image( $name );
  		echo $html->create();
  	}

  	//}}
  	//{{ field

  	/**
  	 * Build form field
  	 *
  	 * @param string  $label
  	 * @param string  $name
  	 * @param mixed   $input
  	 * @param string  $info
  	 * @param string  $layout
  	 * @param boolean $helpAbs
  	 *
  	 * @return IPCht_Html
  	 */
  	public function field( 
  		$label, $name, $input, $info = '', $layout = 'horizontal', $helpAbs = false 
  	)
  	{
  		$contents  = array();

  		//Form label
  		$label 		 = new IPCht_Html( 'label', __( $label, IPCHT_SLUG ), array(
  			'for' => 'input-' . $name
  		));
  		$contents[] =  new IPCht_Html( 'div', $label, array(
  			'class' => 'ipcht-form-label col-lg-3 col-md-4 col-sm-12'
  		));

  		//Form input
  		$inputContents   = array();
  		$inputContents[] = $input;
  		if ( ! empty( $info )) {
  			$inputContents[] = $this->help( $info );
  		}
  		$contents[] =  new IPCht_Html( 'div', $inputContents, array(
  			'class' => 'ipcht-field col-lg-9 col-md-8 col-sm-12'
  		));

  		//Main
  		$class = 'ipcht-field-row';
  		if ( $layout == 'vertical' ) {
  			$class .= ' ipcht-field-y';
  		} else {
  			$class .= ' ipcht-field-x';
  		}
  		if ( $helpAbs ) {
  			$class .= ' ipcht-help-abs';
  		}
  		$field = new IPCht_Html( 'div', $contents, array(
  			'class' => $class
  		));

  		return $field;
  	}

  	//}}
  	//{{ renderField

  	/**
  	 * Render form field
  	 *
  	 * @param string  $label
  	 * @param string  $name
  	 * @param mixed   $input
  	 * @param string  $info
  	 * @param string  $layout
  	 * @param boolean $helpAbs
  	 *
  	 * @return void
  	 */
  	public function renderField( 
  		$label, $name, $input, $info = '', $layout = 'horizontal', $helpAbs = false 
  	)
  	{
  		$html = $this->field( $label, $name, $input, $info, $layout, $helpAbs );
  		echo $html->create();
  	}

  	//}}
  	//{{ help

  	/**
  	 * Render form help
  	 *
  	 * @param string $info
  	 *
  	 * @return IPCht_Html
  	 */
  	public function help( $info ) 
  	{
  		$contents   = array();
  		$contents[] = new IPCht_Html( 
  			'a', 
  			'<i class="ipcht-fa ipcht-fa-question"></i>',
  			array(
  				'class' => 'ipcht-btn-help ipcht-btn ipcht-btn-default',
  				'href'  => '#'
  			)
  		);

  		$contents[] = new IPCht_Html( 
  			'div', 
  			__( $info, IPCHT_SLUG ),
  			array(
  				'class' => 'ipcht-help-content ipcht-hide'
  			)
  		);

  		$help = new IPCht_Html( 
  			'div', 
  			$contents,
  			array(
  				'class' => 'ipcht-help'
  			)
  		);

  		return $help;
  	}

  	//}}
  	//{{ fieldText

  	/**
  	 * Build form field
  	 *
  	 * @param array $config
  	 * @return IPCht_Html
  	 */
  	public function fieldText( $config )
  	{
  		//Set config
  		if ( is_array( $config )) {
  			$config = new IPCht_Config( $config );
  		}

  		$name    = $config->getSetting( 'name', 'name' );
  		$label   = $config->getSetting( 'label', 'Name' );
  		$info    = $config->getSetting( 'info', '' );
      $value   = $config->getSetting( 'inputValue', '' );
      $layout  = $config->getSetting( 'layout', 'horizontal' );
  		$helpAbs = $config->getSetting( 'helpAbs', true );

  		$inputAtts = array();
  		if ( $iatts = $config->getSetting( 'inputAtts' ) ) {
  			$inputAtts = $iatts;
  		}
  		//Create input text
  		$input = $this->input( $name, 'text', $value, $inputAtts );

  		return $this->field($label, $name, $input, $info, $layout, $helpAbs );
  	}

  	//}}
  	//{{ renderFieldText

  	/**
  	 * Render form field
  	 *
  	 * @param array $config
  	 * @return void
  	 */
  	public function renderFieldText( $config ) 
  	{
  		$html = $this->fieldText( $config );
  		echo $html->create();
  	}

  	//}}
  	//{{ fieldName

  	/**
  	 * Build form field name
  	 *
  	 * @param array $config
  	 * @return IPCht_Html
  	 */
  	public function fieldName( $config )
  	{
  		$default = array(
  			'inputAtts'	=> array(
  				'class' => 'ipcht-input ipcht-input-full ipcht-input-v-lg'
  			)
  		);
  		$config = array_merge( $default, $config );

  		return $this->fieldText( $config );
  	}

  	//}}
  	//{{ renderFieldName

  	/**
  	 * Render form field name
  	 *
  	 * @param array $config
  	 * @return void
  	 */
  	public function renderFieldName( $config ) 
  	{
  		$html = $this->fieldName( $config );
  		echo $html->create();
  	}

    //}}
    //{{ fieldTextarea

    /**
     * Build form field with textarea input
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldTextarea( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name    = $config->getSetting( 'name', 'name' );
      $label   = $config->getSetting( 'label', 'Name' );
      $info    = $config->getSetting( 'info', '' );
      $value   = $config->getSetting( 'inputValue', '' );
      $layout  = $config->getSetting( 'layout', 'horizontal' );
      $helpAbs = $config->getSetting( 'helpAbs', true );

      $inputAtts = array();
      if ( $iatts = $config->getSetting( 'inputAtts' ) ) {
        $inputAtts = $iatts;
      }
      //Create input text
      $input = $this->textarea( $name, $value, $inputAtts );

      return $this->field($label, $name, $input, $info, $layout, $helpAbs );
    }

    //}}
    //{{ renderFieldTextarea

    /**
     * Render form field
     *
     * @param array $config
     * @return void
     */
    public function renderFieldTextarea( $config ) 
    {
      $html = $this->fieldTextarea( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldSelect

    /**
     * Build form field with select input
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldSelect( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name     = $config->getSetting( 'name', 'name' );
      $label    = $config->getSetting( 'label', 'Name' );
      $info     = $config->getSetting( 'info', '' );
      $value    = $config->getSetting( 'inputValue', '' );
      $options  = (array)$config->getSetting( 'inputOptions', '' );

      //Create input select
      $input = $this->select( $name, $options, $value );

      return $this->field( $label, $name, $input, $info );
    }

    //}}
    //{{ renderFieldSelect

    /**
     * Render form field with select input
     *
     * @param array $config
     * @return void
     */
    public function renderFieldSelect( $config ) 
    {
      $html = $this->fieldSelect( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldOnOff

    /**
     * Build form field with on off buttons
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldOnOff( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name     = $config->getSetting( 'name', 'name' );
      $label    = $config->getSetting( 'label', 'Name' );
      $info     = $config->getSetting( 'info', '' );
      $value    = $config->getSetting( 'inputValue', '' );
      $onLabel  = $config->getSetting( 'inputOnLabel', 'On' );
      $offLabel = $config->getSetting( 'inputOffLabel', 'Off' );

      //Create input on off
      $input = $this->onOff( $name, $value, $onLabel, $offLabel );

      return $this->field( $label, $name, $input, $info );
    }

    //}}
    //{{ renderFieldOnOff

    /**
     * Render form field
     *
     * @param array $config
     * @return void
     */
    public function renderFieldOnOff( $config ) 
    {
      $html = $this->fieldOnOff( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldColor

    /**
     * Build form field with color input
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldColor( $config )
    {
      $default = array(
        'inputAtts' => array(
          'class'   => 'ipcht-color-picker',
        ),
        'helpAbs' => false
      );
      $config = array_merge( $default, $config );

      return $this->fieldText( $config );
    }

    //}}
    //{{ renderFieldColor

    /**
     * Render form field with color input
     *
     * @param array $config
     * @return void
     */
    public function renderFieldColor( $config ) 
    {
      $html = $this->fieldColor( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldSize

    /**
     * Build form field with input size
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldSize( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name    = $config->getSetting( 'name', 'name' );
      $label   = $config->getSetting( 'label', 'Name' );
      $info    = $config->getSetting( 'info', '' );
      $value   = $config->getSetting( 'inputValue', '' );
      $unit    = $config->getSetting( 'inputUnit', 'px' );

      //Create input text
      $input = $this->inputSize( $name, $value, $unit );

      return $this->field( $label, $name, $input, $info );
    }

    //}}
    //{{ renderFieldSize

    /**
     * Render form field with input size
     *
     * @param array $config
     * @return void
     */
    public function renderFieldSize( $config ) 
    {
      $html = $this->fieldSize( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldImage

    /**
     * Build form field with input image
     *
     * @param array $config
     * @return IPCht_Html
     */
    public function fieldImage( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name    = $config->getSetting( 'name', 'name' );
      $label   = $config->getSetting( 'label', 'Name' );
      $info    = $config->getSetting( 'info', '' );

      //Create input image
      $input = $this->image( $name );

      return $this->field( $label, $name, $input, $info, 'horizontal', true );
    }

    //}}
    //{{ renderFieldImage

    /**
     * Render form field with input image
     *
     * @param array $config
     * @return void
     */
    public function renderFieldImage( $config ) 
    {
      $html = $this->fieldImage( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldBackground

    /**
     * Build form field with input background
     *
     * @param array $config
     * @return string
     */
    public function fieldBackground( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }
      $name    = $config->getSetting( 'name', 'name' );
      $info    = $config->getSetting( 'info', 'object' );
      $bgimage = $config->getSetting( 'bgimage', true, true );
      $color   = $config->getSetting( 'color_default', '#ffffff' );
      $repeat  = $config->getSetting( 'repeat_default', 'no-repeat' );
      $opacity = $config->getSetting( 'repeat_opacity', 20 );

      $fields = '';
      //BG Color
      $config = array(
        'name'       => $name . '_background_color',
        'label'      => 'Background Color',
        'inputValue' => $color,
        'info'       => 'Set the background color of the ' . $info . '.'
      );
      $color   = $this->fieldColor( $config );
      $fields .= $color->create();

      if ( $bgimage )
      {
        //Image
        $config = array(
          'name'  => $name . '_background_image',
          'label' => 'Background Image',
          'info'  => 'Set the background image of the ' . $info . '.'
        );
        $image   = $this->fieldImage( $config );
        $fields .= $image->create();

        //Repeat
        $options = array(
          'no-repeat'   => __( 'No Repeat', IPCHT_SLUG ),
          'repeat-x'    => __( 'Repeat Horizontally', IPCHT_SLUG ),
          'repeat-y'    => __( 'Repeat Vertically', IPCHT_SLUG ),
          'repeat'      => __( 'Repeat All', IPCHT_SLUG ),
        );
        $config  = array(
          'name'  => $name . '_background_repeat',
          'label' => 'Background Repeat',
          'info'  => 'Set the repeat method of the background image.',
          'inputOptions' => $options,
          'inputValue'   => $repeat
        );
        $repeat  = $this->fieldSelect( $config );
        $fields .= $repeat->create();

        //Opacity
        $options = array(
          0    => __( 'None', IPCHT_SLUG ),
          10   => __( '10%', IPCHT_SLUG ),
          20   => __( '20%', IPCHT_SLUG ),
          30   => __( '30%', IPCHT_SLUG ),
          40   => __( '40%', IPCHT_SLUG ),
          50   => __( '50%', IPCHT_SLUG ),
          60   => __( '60%', IPCHT_SLUG ),
          70   => __( '70%', IPCHT_SLUG ),
          80   => __( '80%', IPCHT_SLUG ),
          90   => __( '90%', IPCHT_SLUG )
        );
        $config  = array(
          'name'  => $name . '_background_opacity',
          'label' => 'Background Opacity',
          'info'  => 'Make transparency for the background image.',
          'inputOptions' => $options,
          'inputValue'   => $opacity
        );
        $repeat  = $this->fieldSelect( $config );
        $fields .= $repeat->create();
      }

      return $fields;
    }

    //}}
    //{{ renderFieldBackground

    /**
     * Render form field with input background
     *
     * @param array $config
     * @return void
     */
    public function renderFieldBackground( $config ) 
    {
      $html = $this->fieldBackground( $config );
      echo $html;
    }

    //}}
    //{{ fieldBorder

    /**
     * Build form field with input border
     *
     * @param array $config
     * @return string
     */
    public function fieldBorder( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }
      $name     = $config->getSetting( 'name', 'object' );
      $info     = $config->getSetting( 'info', '' );
      $label    = $config->getSetting( 'label', 'Border' );
      $style    = $config->getSetting( 'border_style', false );
      $color    = $config->getSetting( 'color_default', '#000000' );
      $sdefault = $config->getSetting( 'style_default', 'solid' );

      $inputs = '';
      //Size
      $input   = $this->inputSize( $name . '_border_size', 0 );
      $inputs .= $input->create();

      if ( $style )
      {
        //Style
        $options = array(
          'solid'    => __( 'Solid', IPCHT_SLUG ),
          'dashed'   => __( 'Dashed', IPCHT_SLUG ),
          'dotted'   => __( 'Dotted', IPCHT_SLUG ),
          'double'   => __( 'Double', IPCHT_SLUG )
        );
        $input   = $this->select( $name . '_border_style', $options, $sdefault );
        $inputs .= $input->create();
      }

      //color
      $input = $this->input( $name . '_border_color', 'text', $color, array(
        'class'   => 'ipcht-color-picker'
      ));
      $inputs .= $input->create();

      return $this->field( $label, $name . '_border_size', $inputs, $info );
    }

    //}}
    //{{ renderFieldBorder

    /**
     * Render form field with input border
     *
     * @param array $config
     * @return void
     */
    public function renderFieldBorder( $config ) 
    {
      $html = $this->fieldBorder( $config );
      echo $html->create();
    }

    //}}
    //{{ fieldFontFamily

    /**
     * Build form field with input font family
     *
     * @param array $config
     * @return string
     */
    public function fieldFontFamily( $config )
    {
      //Set config
      if ( is_array( $config )) {
        $config = new IPCht_Config( $config );
      }

      $name    = $config->getSetting( 'name', 'name' );
      $label   = $config->getSetting( 'label', 'Name' );
      $info    = $config->getSetting( 'info', '' );
      $value   = $config->getSetting( 'inputValue', 'roboto' );

      //Create input fancy option
      $option = $this->fancyOption( $name, $value );
      $input  = new IPCht_Html( 'span', $option, array(
        'class'   => 'ipeng-font-family'
      ));

      return $this->field( $label, $name, $input, $info );
    }

    //}}
    //{{ renderFieldFontFamily

    /**
     * Render form field with input font family
     *
     * @param array $config
     * @return void
     */
    public function renderFieldFontFamily( $config ) 
    {
      $html = $this->fieldFontFamily( $config );
      echo $html->create();
    }

  	//}}


  }
}