<?php
/**
 * Class setting model
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Model_Setting' )) 
{
  /**
   * Class for manage main setting
   */
  class IPCht_Model_Setting extends IPCht_Model
  {
    //{{ parameters

    /**
     * Take setting name
     *
     * @var string
     */
    protected $_settingName = '__ipcht_main_setting';

    //}}
    //{{ saveSettings

    /**
     * Save setting 
     *
     * @return void
     */
    public function saveSettings()
    {
      $data   = $this->_getSettingData();
      $result = update_option( $this->_settingName, $data );
      return $result;
    }

    //}}
    //{{ getSettings

    /**
     * Get setting 
     *
     * @return IPCht_Config
     */
    public function getSettings()
    {
      $settings = array();
      $data     = get_option( $this->_settingName );
      if ( ! empty( $data )) 
      {
        $settings = maybe_unserialize( $data );
      }
      $result = new IPCht_Config( $settings );
      return $result;
    }

    //}}
    //{{ _getSettingStructure

    /**
     * Get setting structure
     *
     * @return array
     */
    protected function _getSettingStructure()
    {
      $structure = array(
        'widget_visibility'         => 'term',
        'online_status'             => 'term',
        'restricted'                => 'term',
        //User
        'admin_name'                => 'title',
        'admin_photo'               => 'int',
        'user_photo_type'           => 'term',
        'user_photo'                => 'int',
        //Notification
        'notif_email'               => 'email',
        'notif_chat'                => 'term',
        'notif_chat_offline'        => 'term',
        //Content
        'online_info'               => 'none',
        'offline_info'              => 'none',
        'offline_message'           => 'none',
        'success_offline_message'   => 'none',
        'failed_offline_message'    => 'none',
        'success_register_message'  => 'none',
        'failed_register_message'   => 'none',
        //Form
        'input_name_label'          => 'title',
        'input_email_label'         => 'title',
        'input_phone_label'         => 'title',
        'input_message_label'       => 'title',
        'input_chat_label'          => 'title',
        'submit_chat_label'         => 'title',
        'form_offline_name'         => 'term',
        'form_offline_phone'        => 'term',
        'submit_offline_label'      => 'title',
        'form_register_name'        => 'term',
        'form_register_phone'       => 'term',
        'submit_register_label'     => 'title'

      );
      return $structure;
    }
  }
}
?>
