<?php
/**
 * Class chat model
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Model_Chat' )) 
{
	/**
	 * Class for manage chat data
	 */
	class IPCht_Model_Chat extends IPCht_Model
	{
		/**
		 * Get Chats
		 *
		 * @return int   $userId
		 * @return array
		 */
		public function getChats( $userId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_chat';
			$query  = "
					SELECT * FROM $table
					WHERE
							user_id = $userId
					ORDER BY chat_timestamp
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Chats by session id
		 *
		 * @return int   $sessId
		 * @return array
		 */
		public function getChatsBySession( $sessId )
		{
			global $wpdb;
			$table1 = $wpdb->prefix . 'ipcht_chat';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$table3 = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
						JOIN $table3 
							ON $table1.sess_id = $table3.sess_id
					WHERE
						$table1.sess_id = $sessId

					ORDER BY $table1.chat_timestamp
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Chats by user id
		 *
		 * @return int   $userId
		 * @return array
		 */
		public function getChatsByUser( $userId )
		{
			global $wpdb;
			$table1 = $wpdb->prefix . 'ipcht_chat';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$table3 = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
						JOIN $table3 
							ON $table1.sess_id = $table3.sess_id
					WHERE
						$table1.user_id = $userId

					ORDER BY $table1.chat_timestamp
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Chats by admin to an user id
		 *
		 * @return int    $userId
		 * @return string $date
		 * @return array
		 */
		public function getChatsByAdmin( $userId, $date = null )
		{
			global $wpdb;

			if ( empty( $date )) 
			{
				$now  = time();
				$now -= 5;
				$date = gmdate( 'Y-m-d h:i:s', $now );
			}
			$table1 = $wpdb->prefix . 'ipcht_chat';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$table3 = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
						JOIN $table3 
							ON $table1.sess_id = $table3.sess_id
					WHERE
						$table1.user_id = $userId
						AND
						$table1.chat_originates = 1
						AND
						DATE_FORMAT( $table1.chat_timestamp_gmt, '%Y-%m-%d %h:%i:%s' ) > '$date'

					ORDER BY $table1.chat_timestamp_gmt
			";

			$results = $wpdb->get_results( $query );

			return $results;
		}

		/**
		 * Get Chats by user to an user id
		 *
		 * @return int    $userId
		 * @return string $date
		 * @return array
		 */
		public function getChatsByUserDate( $userId, $date = null )
		{
			global $wpdb;

			if ( empty( $date )) 
			{
				$now  = time();
				$now -= 5;
				$date = gmdate( 'Y-m-d h:i:s', $now );
			}
			$table1 = $wpdb->prefix . 'ipcht_chat';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$table3 = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table1
						JOIN $table2 
							ON $table1.user_id = $table2.user_id
						JOIN $table3 
							ON $table1.sess_id = $table3.sess_id
					WHERE
						$table1.user_id = $userId
						AND
						$table1.chat_originates = 2
						AND
						DATE_FORMAT( $table1.chat_timestamp_gmt, '%Y-%m-%d %h:%i:%s' ) > '$date'

					ORDER BY $table1.chat_timestamp_gmt
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Chat
		 *
		 * @return int   $chatId
		 * @return array
		 */
		public function getChat( $chatId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_chat';
			$query  = "
					SELECT * FROM $table
					WHERE
							chat_id = $chatId
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Insert Chat
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertChat( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_chat';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Chat
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateChat( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_chat';
				$data   = (array)$data;
				$where  = array(
						'chat_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Chat
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteChat( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_chat';
			$where  = array(
					'chat_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

		/**
		 * Delete Chats
		 *
		 * @param  int   $userId
		 * @return void
		 */
		public function deleteChats( $userId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_chat';
			$where  = array(
					'user_id' => absint( $userId )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

	}
}